You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@poi.apache.org by ni...@apache.org on 2015/03/13 18:17:27 UTC

svn commit: r1666517 - /poi/trunk/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java

Author: nick
Date: Fri Mar 13 17:17:27 2015
New Revision: 1666517

URL: http://svn.apache.org/r1666517
Log:
More relation types

Modified:
    poi/trunk/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java

Modified: poi/trunk/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java
URL: http://svn.apache.org/viewvc/poi/trunk/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java?rev=1666517&r1=1666516&r2=1666517&view=diff
==============================================================================
--- poi/trunk/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java (original)
+++ poi/trunk/src/ooxml/java/org/apache/poi/openxml4j/opc/PackageRelationshipTypes.java Fri Mar 13 17:17:27 2015
@@ -19,12 +19,8 @@ package org.apache.poi.openxml4j.opc;
 
 /**
  * Relationship types.
- *
- * @author Julien Chable
- * @version 0.2
  */
 public interface PackageRelationshipTypes {
-
 	/**
 	 * Core properties relationship type.
      *
@@ -70,16 +66,26 @@ public interface PackageRelationshipType
 	 */
 	String EXTENDED_PROPERTIES = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/extended-properties";
 
+    /**
+     * Extended properties relationship type for strict ooxml.
+     */
+    String STRICT_EXTENDED_PROPERTIES = "http://purl.oclc.org/ooxml/officeDocument/relationships/extendedProperties";
+
 	/**
 	 * Custom properties relationship type.
 	 */
 	String CUSTOM_PROPERTIES = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/custom-properties";
 	
 	/**
 	 * Core properties relationship type.
 	 */
 	String CORE_DOCUMENT = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
 
+    /**
+     * Core document relationship type for strict ooxml.
+     */
+    String STRICT_CORE_DOCUMENT = "http://purl.oclc.org/ooxml/officeDocument/relationships/officeDocument";
+
 	/**
 	 * Custom XML relationship type.
 	 */
@@ -104,4 +110,9 @@ public interface PackageRelationshipType
 	 * External Link to another Document
 	 */
 	String EXTERNAL_LINK_PATH = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/externalLinkPath";
+
+	/**
+	 * Visio 2010 VSDX equivalent of package {@link #CORE_DOCUMENT}
+	 */
+	String VISIO_CORE_DOCUMENT = "http://schemas.microsoft.com/visio/2010/relationships/document";
 }



---------------------------------------------------------------------
@@ -70,16 +66,26 @@ public interface PackageRelationshipType
 	
 	/**
-	 * Core properties relationship type.
+	 * Core document relationship type.
 	 */
 	String CORE_DOCUMENT = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
To unsubscribe, e-mail: commits-unsubscribe@poi.apache.org
For additional commands, e-mail: commits-help@poi.apache.org